<!--
    =====================================
    generator=datazen
    version=1.7.7
    hash=0e3889659cc0169c550ea01f0d5875f6
    =====================================
-->

# blizzard-api ([0.3.4](https://pypi.org/project/blizzard-api/))

[![python](https://img.shields.io/pypi/pyversions/blizzard-api.svg)](https://pypi.org/project/blizzard-api/)
![Build Status](https://github.com/vkottler/keybinds/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/vkottler/keybinds/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/vkottler/keybinds)

*Interact with Blizard's game-data API.*
